summaryrefslogtreecommitdiffstats
path: root/ash/wm/shelf_layout_manager.h
diff options
context:
space:
mode:
authorsky@chromium.org <sky@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-03-21 20:52:15 +0000
committersky@chromium.org <sky@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-03-21 20:52:15 +0000
commita160baecdd408a80a6861635a398011622f04718 (patch)
tree8fd64fc6a97cdb3a5900b3303edb70ba267bd28e /ash/wm/shelf_layout_manager.h
parent1cd7a4bdffafd7c84f0846d9cce59c921ae8ac0e (diff)
downloadchromium_src-a160baecdd408a80a6861635a398011622f04718.zip
chromium_src-a160baecdd408a80a6861635a398011622f04718.tar.gz
chromium_src-a160baecdd408a80a6861635a398011622f04718.tar.bz2
Makes the tray not paint a background if the launcher is painting a
background. I refactored the animation class to allow both launcher and tray to share it. BUG=118357 TEST=visual test, see bug. R=sadrul@chromium.org Review URL: https://chromiumcodereview.appspot.com/9820002 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@128052 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'ash/wm/shelf_layout_manager.h')
-rw-r--r--ash/wm/shelf_layout_manager.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/ash/wm/shelf_layout_manager.h b/ash/wm/shelf_layout_manager.h
index 47000b0..5396e56 100644
--- a/ash/wm/shelf_layout_manager.h
+++ b/ash/wm/shelf_layout_manager.h
@@ -136,8 +136,11 @@ class ASH_EXPORT ShelfLayoutManager : public aura::LayoutManager {
void CalculateTargetBounds(const State& state,
TargetBounds* target_bounds) const;
- // Returns whether the shelf should draw a background.
- bool GetShelfRendersBackground() const;
+ // Updates the background of the shelf.
+ void UpdateShelfBackground(BackgroundAnimator::ChangeType type);
+
+ // Returns whether the launcher should draw a background.
+ bool GetLauncherPaintsBackground() const;
// True when inside LayoutShelf method. Used to prevent calling LayoutShelf
// again from SetChildBounds().